/*==========================================================================
 =                                                                         =
 =                        Project CTI-Print                                =
 =                                                                         =
 = Author:                                                                 =
 =   Panos Dimakopoulos, Systems Programmer,                               =
 =   Computer Technology Institute,                                        =
 =   Division of Computing Facilities,                                     =
 =   P.O. Box 1122,                                                        =
 =   261 10  Patras,                                                       =
 =   Greece                                                                =
 =   (e-mail: dimakop@cti.gr)                                              =
 =   Tel: +30 61 992061                                                    =
 =   Fax: +30 61 993973                                                    =
 =                                                                         =
 = Created by Patrick Powell  <papowell@sdsu.edu>                          =
 =   for LPRng software Sat Aug 26 06:54:25 PDT 1995                       =
 ==========================================================================*/


/*==========================================================================
  Version CTI-LPRng-1.0
  =========================================================================*/


/*
 * $Id: sendjob.c,v 1.8 1996/07/24 21:11:01 papowell Exp $
 */

#include "portable.h"
#include "common.h"
#include "hp4.h"

/*
 * send job to the remote printer
 */

void sendjob(fd, sockfd)
int    fd;
int    sockfd;
{
	int 	rdcnt;
	int i;
	char *s, *ps;
	int discard = 0;

	/* read an input line */
	log(9,"sendjob: reading input");
	/* set up the options using PJL.
     * Note: you may need to do this again in PCL or PostScript
	 */
	job_page_set();
	if( (rdcnt=file_readline(fd,sendline,sizeof(sendline)-1)) > 0){
		log(6,"sendjob: read %d '%s'", rdcnt,sendline);
		/* try to determine which mode you are in */
		if( literal || autodetect ){
			log(2,"Entering Autodetect Mode");
			mode = LITERAL;
		} else {
			if( (ps = strstr(sendline, "%!" )) ){
				for( s = sendline; ps && s!=ps; ++s ){
					/* we must have a control char string */
					if( !iscntrl(*s) ) ps = 0;
				}
			}
			if( ps && cartridge ){
				mode = POSTSCRIPT ;
				log(2,"Entering POSTSCRIPT Mode");
				setps_on();
			} else {
				mode = PCL ;
				log(2,"Entering PCL Mode");
				setpcl_on();
				page_set();
				if( ps ){
					s = UNABLE;
					i = strlen(s);
					writecn(sockfd,s,i);
				}
			}
		}
		log(4,"sendjob: setting duplex");
		pr_duplex();
		log(2,"Transferring file");
		if( !discard && rdcnt != writecn(sockfd, sendline, rdcnt) ){
			logerr_die(2,"Cannot write what read (%d bytes)",rdcnt);
		}
		log(4,"sendjob: wrote first line '%s'", sendline );
		/* now we read the rest of the file */
		if( !discard ){
			while( (rdcnt=read(fd,sendline,sizeof(sendline)-1)) > 0){
				log(4,"sendjob: next line '%s'", sendline );
				if( rdcnt != writecn(sockfd, sendline, rdcnt ) ){
					logerr_die(2,"Cannot write what read (%d bytes)",rdcnt);
				}
			}
		}
    }
	log(2,"Finished transferring file");
}
